@@ -18,7 +18,7 @@
 #ifndef BPSKDEMODULATOR_H
 #define BPSKDEMODULATOR_H
 
-#include <complex.h>
+#include <complex>
 #include "cpskdemodulator.h"
 
 
@@ -32,7 +32,9 @@ public:
 	~BPskDemodulator();
 protected:	
 /** Decodes a BPSK Symbol */
-void DecodeSymbol( double_complex newsamp);
+//void DecodeSymbol( complex<double> newsamp);
+void DecodeSymbol( double);
+
 void CalcQuality(double);
 private:
 	bool GetBPSKSymb();
