@@ -18,6 +18,9 @@
 
 CDemodulator::CDemodulator()
 {
+UseAfc = true;
+Squelch = true;
+Threshold= 50;
 }
 
 CDemodulator::~CDemodulator()
@@ -35,3 +38,31 @@ double CDemodulator::getRxFrequency(void)
 {
 return RxFrequency;
 }
+
+void CDemodulator::setThreshold(int value)
+{
+Threshold= value;
+}
+
+void CDemodulator::setSquelch(bool OnOff)
+{
+Squelch=OnOff;
+}
+
+bool CDemodulator::getAFC()
+{
+return UseAfc;
+}
+bool CDemodulator::getSquelchState()
+{
+return Squelch;
+}
+std::complex<float> * CDemodulator::getPhasePointer()
+{
+return 0;
+}
+int CDemodulator::getThreshold()
+{
+return Threshold;
+}
+
