@@ -16,18 +16,14 @@
 
 #include "cmodulator.h"
 
-CModulator::CModulator(int FS,CTxdisplay *txwindow)
+CModulator::CModulator(int FS,CTxBuffer *TxBuffer)
 {
 
 SampleRate=FS;
-tx=txwindow;
+Buffer=TxBuffer;
 
 }
 CModulator::~CModulator()
 {
 }
 
-void CModulator::setMode(Mode modus)
-{
-PSKMode = modus;
-}
