@@ -39,15 +39,14 @@ else
   /** Closes the open Device */
 bool Input::close_Device()
 {
-int i;
+
 if (fd >= 0)
-	i=close(fd);
-	if ( i!=0)
-		i=errno;
+	close(fd);
 fd = -1;
 return true;
 }
 
 
+
 	
 
